@@ -25,9 +25,9 @@ except ImportError:
     mspack = None
 
 # Import ioflo libs
-from ioflo.base.odicting import odict
-from ioflo.base import aiding
-from ioflo.base import storing
+from ioflo.aid.odicting import odict
+from ioflo.aid.timing import StoreTimer
+from ioflo.base.storing import Store
 
 # Import raet libs
 from .abiding import *  # import globals
@@ -66,7 +66,7 @@ class Stack(object):
         '''
         Setup Stack instance
         '''
-        self.store = store or storing.Store(stamp=0.0)
+        self.store = store or Store(stamp=0.0)
 
         self.version = version
         self.main = main
@@ -103,7 +103,7 @@ class Stack(object):
         self.rxes = rxes if rxes is not None else deque() # udp packets received
         self.txes = txes if txes is not None else deque() # udp packet to transmit
         self.stats = stats if stats is not None else odict() # udp statistics
-        self.statTimer = aiding.StoreTimer(self.store)
+        self.statTimer = StoreTimer(self.store)
 
     @property
     def name(self):
@@ -279,14 +279,14 @@ class Stack(object):
         try:
             rx, ra = self.server.receive()  # if no data the duple is ('',None)
         except socket.error as ex:
-            if ex.errno == errno.ECONNRESET:
+            err = raeting.get_exception_error(ex)
+            if err == errno.ECONNRESET:
                 return False
         if not rx:  # no received data
             return False
         self.rxes.append((rx, ra))     # duple = ( packet, source address)
         return True
 
-
     def serviceReceives(self):
         '''
         Retrieve from server all recieved and put on the rxes deque
@@ -391,7 +391,6 @@ class Stack(object):
             raise raeting.StackError(msg)
         self.txes.append((packed, self.remotes[duid].ha))
 
-
     def _handleOneTx(self, laters, blocks):
         '''
         Handle one message on .txes deque
@@ -408,7 +407,8 @@ class Stack(object):
         try:
             self.server.send(tx, ta)
         except socket.error as ex:
-            if (ex.errno in [errno.EAGAIN, errno.EWOULDBLOCK,
+            err = raeting.get_exception_error(ex)
+            if (err in [errno.EAGAIN, errno.EWOULDBLOCK,
                              errno.ENETUNREACH, errno.ETIME,
                              errno.EHOSTUNREACH, errno.EHOSTDOWN,
                              errno.ECONNRESET]):
